@@ -17,6 +17,9 @@ use std::io::prelude::*;
 use std::process::{Command, ExitStatus, Output, Stdio};
 use types::{ErrorInfo, ScriptError, ScriptOptions};
 
+#[cfg(not(windows))]
+use users::get_current_username;
+
 /// Returns the exit code
 fn get_exit_code(code: ExitStatus) -> i32 {
     if !code.success() {
@@ -53,11 +56,27 @@ fn delete_file(file: &str) {
     remove_file(file).unwrap_or(());
 }
 
+#[cfg(windows)]
+fn get_additional_temp_path() -> Option<String> {
+    None
+}
+
+#[cfg(not(windows))]
+fn get_additional_temp_path() -> Option<String> {
+    get_current_username()
+}
+
 fn create_script_file(script: &String) -> Result<String, Error> {
     let name = env!("CARGO_PKG_NAME");
     let file_name: String = thread_rng().gen_ascii_chars().take(10).collect();
 
     let mut file_path = env::temp_dir();
+
+    match get_additional_temp_path() {
+        Some(additional_path) => file_path.push(additional_path),
+        None => {}
+    };
+
     file_path.push(name);
 
     // create parent directory
